from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TimingCls:
	"""Timing commands group definition. 32 total commands, 11 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("timing", core, parent)

	@property
	def all(self):
		"""all commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_all'):
			from .All import AllCls
			self._all = AllCls(self._core, self._cmd_group)
		return self._all

	@property
	def dcycle(self):
		"""dcycle commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_dcycle'):
			from .Dcycle import DcycleCls
			self._dcycle = DcycleCls(self._core, self._cmd_group)
		return self._dcycle

	@property
	def dratio(self):
		"""dratio commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_dratio'):
			from .Dratio import DratioCls
			self._dratio = DratioCls(self._core, self._cmd_group)
		return self._dratio

	@property
	def fall(self):
		"""fall commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_fall'):
			from .Fall import FallCls
			self._fall = FallCls(self._core, self._cmd_group)
		return self._fall

	@property
	def off(self):
		"""off commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_off'):
			from .Off import OffCls
			self._off = OffCls(self._core, self._cmd_group)
		return self._off

	@property
	def prf(self):
		"""prf commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_prf'):
			from .Prf import PrfCls
			self._prf = PrfCls(self._core, self._cmd_group)
		return self._prf

	@property
	def pri(self):
		"""pri commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_pri'):
			from .Pri import PriCls
			self._pri = PriCls(self._core, self._cmd_group)
		return self._pri

	@property
	def pwidth(self):
		"""pwidth commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_pwidth'):
			from .Pwidth import PwidthCls
			self._pwidth = PwidthCls(self._core, self._cmd_group)
		return self._pwidth

	@property
	def rise(self):
		"""rise commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_rise'):
			from .Rise import RiseCls
			self._rise = RiseCls(self._core, self._cmd_group)
		return self._rise

	@property
	def settling(self):
		"""settling commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_settling'):
			from .Settling import SettlingCls
			self._settling = SettlingCls(self._core, self._cmd_group)
		return self._settling

	@property
	def tstamp(self):
		"""tstamp commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_tstamp'):
			from .Tstamp import TstampCls
			self._tstamp = TstampCls(self._core, self._cmd_group)
		return self._tstamp

	def clone(self) -> 'TimingCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TimingCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PhaseCls:
	"""Phase commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("phase", core, parent)

	def set(self, xaxis: enums.PulsePhaseItems, yaxis: enums.YaXisItems, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:DISTribution:PHASe \n
		Snippet: driver.applications.k6Pulse.calculate.distribution.phase.set(xaxis = enums.PulsePhaseItems.DEViation, yaxis = enums.YaXisItems.COUNt, window = repcap.Window.Default) \n
		Configures the Parameter Distribution result display. \n
			:param xaxis: POINt | PPPHase | RERRor | PERRor | DEViation Pulse parameter to be displayed on the x-axis. For a description of the available parameters see 'Phase parameters'. POINt Pulse phase at measurement point PPPHase Pulse-Pulse Phase Difference RERRor Phase Error (RMS) PERRor Phase Error (Peak) DEViation Phase Deviation
			:param yaxis: COUNt | OCCurrence Parameter to be displayed on the y-axis. COUNt Number of pulses in which the parameter value occurred. OCCurrence Percentage of all measured pulses in which the parameter value occurred.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('xaxis', xaxis, DataType.Enum, enums.PulsePhaseItems), ArgSingle('yaxis', yaxis, DataType.Enum, enums.YaXisItems))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:DISTribution:PHASe {param}'.rstrip())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class InputPyCls:
	"""InputPy commands group definition. 29 total commands, 15 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("inputPy", core, parent)

	@property
	def attenuation(self):
		"""attenuation commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_attenuation'):
			from .Attenuation import AttenuationCls
			self._attenuation = AttenuationCls(self._core, self._cmd_group)
		return self._attenuation

	@property
	def connector(self):
		"""connector commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_connector'):
			from .Connector import ConnectorCls
			self._connector = ConnectorCls(self._core, self._cmd_group)
		return self._connector

	@property
	def coupling(self):
		"""coupling commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_coupling'):
			from .Coupling import CouplingCls
			self._coupling = CouplingCls(self._core, self._cmd_group)
		return self._coupling

	@property
	def diq(self):
		"""diq commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_diq'):
			from .Diq import DiqCls
			self._diq = DiqCls(self._core, self._cmd_group)
		return self._diq

	@property
	def dpath(self):
		"""dpath commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dpath'):
			from .Dpath import DpathCls
			self._dpath = DpathCls(self._core, self._cmd_group)
		return self._dpath

	@property
	def eatt(self):
		"""eatt commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_eatt'):
			from .Eatt import EattCls
			self._eatt = EattCls(self._core, self._cmd_group)
		return self._eatt

	@property
	def egain(self):
		"""egain commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_egain'):
			from .Egain import EgainCls
			self._egain = EgainCls(self._core, self._cmd_group)
		return self._egain

	@property
	def file(self):
		"""file commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_file'):
			from .File import FileCls
			self._file = FileCls(self._core, self._cmd_group)
		return self._file

	@property
	def filterPy(self):
		"""filterPy commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_filterPy'):
			from .FilterPy import FilterPyCls
			self._filterPy = FilterPyCls(self._core, self._cmd_group)
		return self._filterPy

	@property
	def gain(self):
		"""gain commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_gain'):
			from .Gain import GainCls
			self._gain = GainCls(self._core, self._cmd_group)
		return self._gain

	@property
	def impedance(self):
		"""impedance commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_impedance'):
			from .Impedance import ImpedanceCls
			self._impedance = ImpedanceCls(self._core, self._cmd_group)
		return self._impedance

	@property
	def iq(self):
		"""iq commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_iq'):
			from .Iq import IqCls
			self._iq = IqCls(self._core, self._cmd_group)
		return self._iq

	@property
	def rf(self):
		"""rf commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_rf'):
			from .Rf import RfCls
			self._rf = RfCls(self._core, self._cmd_group)
		return self._rf

	@property
	def select(self):
		"""select commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_select'):
			from .Select import SelectCls
			self._select = SelectCls(self._core, self._cmd_group)
		return self._select

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	def clone(self) -> 'InputPyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = InputPyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TriggerCls:
	"""Trigger commands group definition. 5 total commands, 4 Subgroups, 0 group commands
	Repeated Capability: TriggerPort, default value after init: TriggerPort.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("trigger", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_triggerPort_get', 'repcap_triggerPort_set', repcap.TriggerPort.Nr1)

	def repcap_triggerPort_set(self, triggerPort: repcap.TriggerPort) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to TriggerPort.Default
		Default value after init: TriggerPort.Nr1"""
		self._cmd_group.set_repcap_enum_value(triggerPort)

	def repcap_triggerPort_get(self) -> repcap.TriggerPort:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def direction(self):
		"""direction commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_direction'):
			from .Direction import DirectionCls
			self._direction = DirectionCls(self._core, self._cmd_group)
		return self._direction

	@property
	def level(self):
		"""level commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_level'):
			from .Level import LevelCls
			self._level = LevelCls(self._core, self._cmd_group)
		return self._level

	@property
	def otype(self):
		"""otype commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_otype'):
			from .Otype import OtypeCls
			self._otype = OtypeCls(self._core, self._cmd_group)
		return self._otype

	@property
	def pulse(self):
		"""pulse commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_pulse'):
			from .Pulse import PulseCls
			self._pulse = PulseCls(self._core, self._cmd_group)
		return self._pulse

	def clone(self) -> 'TriggerCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TriggerCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrequencyCls:
	"""Frequency commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frequency", core, parent)

	@property
	def y(self):
		"""y commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_y'):
			from .Y import YCls
			self._y = YCls(self._core, self._cmd_group)
		return self._y

	@property
	def x(self):
		"""x commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_x'):
			from .X import XCls
			self._x = XCls(self._core, self._cmd_group)
		return self._x

	def set(self, yaxis: enums.PulseFreqItems, xaxis: enums.PulseAxisItems, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:TRENd:FREQuency \n
		Snippet: driver.applications.k6Pulse.calculate.trend.frequency.set(yaxis = enums.PulseFreqItems.CRATe, xaxis = enums.PulseAxisItems.DCYCle, window = repcap.Window.Default) \n
		Configures the Parameter Trend result display for time trends. This command defines both x-axis and y-axis parameters in
		one step. It is equivalent to the two subsequent commands: CALCulate<n>:TRENd:TIMing:X TSTamp | PNUMber (see method RsFsw.
		Applications.K6_Pulse.Calculate.Trend.Timing.X.set) CALCulate<n>:TRENd:FREQuency:Y <YAxis> (see method RsFsw.Applications.
		K6_Pulse.Calculate.Trend.Frequency.Y.set) \n
			:param yaxis: POINt | PPFRequency | RERRor | PERRor | DEViation | CRATe Pulse parameter to be displayed on the y-axis. For a description of the available parameters see 'Frequency parameters'. POINt Frequency at measurement point PPFRequency Pulse-Pulse Frequency Difference RERRor Frequency Error (RMS) PERRor Frequency Error (Peak) DEViation Frequency Deviation CRATe Chirp Rate
			:param xaxis: PNUMber | TSTamp | SETTling | RISE | FALL | PWIDth | OFF | DRATio | DCYCle | PRI | PRF Pulse parameter to be displayed on the x-axis. For a description of the available parameters see 'Timing parameters'. TSTamp Timestamp PNUMber The pulse numbers are represented on the x-axis (available numbers can be queried using [SENSe:]PULSe:NUMBer?) . Intervals without pulses are not displayed. SETTling Settling Time RISE Rise Time FALL Fall Time PWIDth Pulse Width (ON Time) OFF Off Time DRATio Duty Ratio DCYCle Duty Cycle (%) PRI Pulse Repetition Interval PRF Pulse Repetition Frequency (Hz)
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('yaxis', yaxis, DataType.Enum, enums.PulseFreqItems), ArgSingle('xaxis', xaxis, DataType.Enum, enums.PulseAxisItems))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:TRENd:FREQuency {param}'.rstrip())

	def clone(self) -> 'FrequencyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FrequencyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal.Types import DataType
from .........Internal.StructBase import StructBase
from .........Internal.ArgStruct import ArgStruct
from .........Internal.ArgSingleList import ArgSingleList
from .........Internal.ArgSingle import ArgSingle
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LimitCls:
	"""Limit commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("limit", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def set(self, lower_limit: float, upper_limit: float, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:TABLe:FREQuency:RERRor:LIMit \n
		Snippet: driver.applications.k6Pulse.calculate.table.frequency.rerror.limit.set(lower_limit = 1.0, upper_limit = 1.0, window = repcap.Window.Default) \n
		Defines the valid value range for the limit check for the selected parameter if limit check is active
		(CALCulate<n>:TABLe:<ParameterGroup>:<Parameter>:LIMit:STATeON) . Commands for the parameter group <TSIDelobe> are only
		available if the additional option R&S FSW-K6S is installed. For details on the individual parameters see 'Pulse
		parameters'. \n
			:param lower_limit: Lower limit of the valid value range. Unit: S
			:param upper_limit: Upper limit of the valid value range. Unit: S
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('lower_limit', lower_limit, DataType.Float), ArgSingle('upper_limit', upper_limit, DataType.Float))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:TABLe:FREQuency:RERRor:LIMit {param}'.rstrip())

	# noinspection PyTypeChecker
	class LimitStruct(StructBase):
		"""Response structure. Fields: \n
			- Lower_Limit: float: Lower limit of the valid value range. Unit: S
			- Upper_Limit: float: Upper limit of the valid value range. Unit: S"""
		__meta_args_list = [
			ArgStruct.scalar_float('Lower_Limit'),
			ArgStruct.scalar_float('Upper_Limit')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Lower_Limit: float = None
			self.Upper_Limit: float = None

	def get(self, window=repcap.Window.Default) -> LimitStruct:
		"""SCPI: CALCulate<n>:TABLe:FREQuency:RERRor:LIMit \n
		Snippet: value: LimitStruct = driver.applications.k6Pulse.calculate.table.frequency.rerror.limit.get(window = repcap.Window.Default) \n
		Defines the valid value range for the limit check for the selected parameter if limit check is active
		(CALCulate<n>:TABLe:<ParameterGroup>:<Parameter>:LIMit:STATeON) . Commands for the parameter group <TSIDelobe> are only
		available if the additional option R&S FSW-K6S is installed. For details on the individual parameters see 'Pulse
		parameters'. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: structure: for return value, see the help for LimitStruct structure arguments."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		return self._core.io.query_struct(f'CALCulate{window_cmd_val}:TABLe:FREQuency:RERRor:LIMit?', self.__class__.LimitStruct())

	def clone(self) -> 'LimitCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LimitCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ListPyCls:
	"""ListPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("listPy", core, parent)

	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:HARMonics:LIST \n
		Snippet: value: float = driver.calculate.marker.function.harmonics.listPy.get(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command queries the position of the harmonics. To get a valid result, you have to perform a complete measurement
		with synchronization to the end of the measurement before reading out the result. This is only possible for single sweep
		mode. See also method RsFsw.Applications.K10x_Lte.Initiate.Continuous.set. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: harmonics: Returns one value for every harmonic. The first value is the absolute power of the first harmonic. The unit is variable. The other values are power levels relative to the first harmonic. The unit for these is dB."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:HARMonics:LIST?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BeginCls:
	"""Begin commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("begin", core, parent)

	def set(self, time: float, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:HOPDetection:POWer:OFFSet:BEGin \n
		Snippet: driver.applications.k60Transient.calculate.hopDetection.power.offset.begin.set(time = 1.0, window = repcap.Window.Default) \n
		Defines the beginning of the measurement range as an offset in seconds from the hop start. This command is only available
		if the reference is EDGE (see method RsFsw.Applications.K60_Transient.Calculate.HopDetection.Power.Reference.set) . For
		details on the measurement range parameters see 'Measurement range'. \n
			:param time: Unit: S
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.decimal_value_to_str(time)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:HOPDetection:POWer:OFFSet:BEGin {param}')

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:HOPDetection:POWer:OFFSet:BEGin \n
		Snippet: value: float = driver.applications.k60Transient.calculate.hopDetection.power.offset.begin.get(window = repcap.Window.Default) \n
		Defines the beginning of the measurement range as an offset in seconds from the hop start. This command is only available
		if the reference is EDGE (see method RsFsw.Applications.K60_Transient.Calculate.HopDetection.Power.Reference.set) . For
		details on the measurement range parameters see 'Measurement range'. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: time: Unit: S"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:HOPDetection:POWer:OFFSet:BEGin?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IfFrequencyCls:
	"""IfFrequency commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ifFrequency", core, parent)

	def set(self, frequency: float, outputConnector=repcap.OutputConnector.Default) -> None:
		"""SCPI: OUTPut<up>:IF:IFFRequency \n
		Snippet: driver.output.ifreq.ifFrequency.set(frequency = 1.0, outputConnector = repcap.OutputConnector.Default) \n
		This command defines the frequency for the IF output of the R&S FSW. The IF frequency of the signal is converted
		accordingly. This command is available in the time domain and if the IF/VIDEO/DEMOD output is configured for IF. If the
		[IF WIDE OUTPUT] connector is used (TRACe:IQ:WBANd ON, see method RsFsw.Applications.K17_Mcgd.Trace.Iq.Wband.State.set) ,
		this command is available as a query only. It returns the used IF output frequency which is defined automatically by the
		application according to the center frequency. For more information see 'IF and video signal output'. \n
			:param frequency: Unit: HZ
			:param outputConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
		"""
		param = Conversions.decimal_value_to_str(frequency)
		outputConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(outputConnector, repcap.OutputConnector)
		self._core.io.write(f'OUTPut{outputConnector_cmd_val}:IF:IFFRequency {param}')

	def get(self, outputConnector=repcap.OutputConnector.Default) -> float:
		"""SCPI: OUTPut<up>:IF:IFFRequency \n
		Snippet: value: float = driver.output.ifreq.ifFrequency.get(outputConnector = repcap.OutputConnector.Default) \n
		This command defines the frequency for the IF output of the R&S FSW. The IF frequency of the signal is converted
		accordingly. This command is available in the time domain and if the IF/VIDEO/DEMOD output is configured for IF. If the
		[IF WIDE OUTPUT] connector is used (TRACe:IQ:WBANd ON, see method RsFsw.Applications.K17_Mcgd.Trace.Iq.Wband.State.set) ,
		this command is available as a query only. It returns the used IF output frequency which is defined automatically by the
		application according to the center frequency. For more information see 'IF and video signal output'. \n
			:param outputConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
			:return: frequency: Unit: HZ"""
		outputConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(outputConnector, repcap.OutputConnector)
		response = self._core.io.query_str(f'OUTPut{outputConnector_cmd_val}:IF:IFFRequency?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, stimulus: float, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:MSRA:ALINe[:VALue] \n
		Snippet: driver.applications.k6Pulse.calculate.msra.aline.value.set(stimulus = 1.0, window = repcap.Window.Default) \n
		This command defines the position of the analysis line for all time-based windows in all MSRA secondary applications and
		the MSRA primary application. \n
			:param stimulus: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.decimal_value_to_str(stimulus)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:MSRA:ALINe:VALue {param}')

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:MSRA:ALINe[:VALue] \n
		Snippet: value: float = driver.applications.k6Pulse.calculate.msra.aline.value.get(window = repcap.Window.Default) \n
		This command defines the position of the analysis line for all time-based windows in all MSRA secondary applications and
		the MSRA primary application. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: stimulus: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MSRA:ALINe:VALue?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UpperCls:
	"""Upper commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("upper", core, parent)

	def set(self, percentage: float, window=repcap.Window.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>]:PSPectrum:COLor:UPPer \n
		Snippet: driver.display.window.pspectrum.color.upper.set(percentage = 1.0, window = repcap.Window.Default) \n
		This command sets the upper percentage boundary of the persistence spectrum. \n
			:param percentage: Statistical frequency percentage. Range: 0.01 to 100, Unit: %
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
		"""
		param = Conversions.decimal_value_to_str(percentage)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:PSPectrum:COLor:UPPer {param}')

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: DISPlay[:WINDow<n>]:PSPectrum:COLor:UPPer \n
		Snippet: value: float = driver.display.window.pspectrum.color.upper.get(window = repcap.Window.Default) \n
		This command sets the upper percentage boundary of the persistence spectrum. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:return: percentage: Statistical frequency percentage. Range: 0.01 to 100, Unit: %"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:PSPectrum:COLor:UPPer?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SoffsetCls:
	"""Soffset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("soffset", core, parent)

	def set(self, sensor_offset: float) -> None:
		"""SCPI: [SENSe]:PMETer:SOFFset \n
		Snippet: driver.applications.k18AmplifierEt.sense.pmeter.soffset.set(sensor_offset = 1.0) \n
		Takes the specified offset into account for the measured power. Only available if [SENSe:]PMETer{p}:ROFFset[:STATe] is
		disabled. \n
			:param sensor_offset: Unit: DB
		"""
		param = Conversions.decimal_value_to_str(sensor_offset)
		self._core.io.write(f'SENSe:PMETer:SOFFset {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:PMETer:SOFFset \n
		Snippet: value: float = driver.applications.k18AmplifierEt.sense.pmeter.soffset.get() \n
		Takes the specified offset into account for the measured power. Only available if [SENSe:]PMETer{p}:ROFFset[:STATe] is
		disabled. \n
			:return: sensor_offset: Unit: DB"""
		response = self._core.io.query_str(f'SENSe:PMETer:SOFFset?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class WriteCls:
	"""Write commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("write", core, parent)

	def set(self) -> None:
		"""SCPI: CONFigure:REFSignal:CWF:WRITe \n
		Snippet: driver.applications.k18AmplifierEt.configure.refSignal.cwf.write.set() \n
		This command loads a reference signal based on a waveform file into the application. When you turn on the reference
		signal export to the generator (method RsFsw.Applications.K18_AmplifierEt.Configure.RefSignal.Cwf.EtGenerator.State.set) ,
		the command also transfers the waveform file to the generator. Make sure to synchronize with *OPC? or *WAI to make sure
		that the command was successfully applied on the generator before sending the next command. \n
		"""
		self._core.io.write(f'CONFigure:REFSignal:CWF:WRITe')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: CONFigure:REFSignal:CWF:WRITe \n
		Snippet: driver.applications.k18AmplifierEt.configure.refSignal.cwf.write.set_with_opc() \n
		This command loads a reference signal based on a waveform file into the application. When you turn on the reference
		signal export to the generator (method RsFsw.Applications.K18_AmplifierEt.Configure.RefSignal.Cwf.EtGenerator.State.set) ,
		the command also transfers the waveform file to the generator. Make sure to synchronize with *OPC? or *WAI to make sure
		that the command was successfully applied on the generator before sending the next command. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CONFigure:REFSignal:CWF:WRITe', opc_timeout_ms)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IdnCls:
	"""Idn commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("idn", core, parent)

	def get(self) -> str:
		"""SCPI: SYSTem:COMMunicate:RDEVice:OSCilloscope:IDN \n
		Snippet: value: str = driver.applications.k9X11Ad.system.communicate.rdevice.oscilloscope.idn.get() \n
		Returns the identification string of the oscilloscope connected to the R&S FSW. \n
			:return: idn: No help available"""
		response = self._core.io.query_str(f'SYSTem:COMMunicate:RDEVice:OSCilloscope:IDN?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CaclrCls:
	"""Caclr commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("caclr", core, parent)

	def set(self, state: float or bool) -> None:
		"""SCPI: CONFigure[:NR5G]:CACLr \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.caclr.set(state = 1.0) \n
		No command help available \n
			:param state: (float or boolean) No help available
		"""
		param = Conversions.decimal_or_bool_value_to_str(state)
		self._core.io.write(f'CONFigure:NR5G:CACLr {param}')

	def get(self) -> float or bool:
		"""SCPI: CONFigure[:NR5G]:CACLr \n
		Snippet: value: float or bool = driver.applications.k14Xnr5G.configure.nr5G.caclr.get() \n
		No command help available \n
			:return: state: (float or boolean) No help available"""
		response = self._core.io.query_str(f'CONFigure:NR5G:CACLr?')
		return Conversions.str_to_float_or_bool(response)



from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup
from ............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ToCls:
	"""To commands group definition. 5 total commands, 4 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("to", core, parent)

	@property
	def duration(self):
		"""duration commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_duration'):
			from .Duration import DurationCls
			self._duration = DurationCls(self._core, self._cmd_group)
		return self._duration

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def period(self):
		"""period commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_period'):
			from .Period import PeriodCls
			self._period = PeriodCls(self._core, self._cmd_group)
		return self._period

	@property
	def slots(self):
		"""slots commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_slots'):
			from .Slots import SlotsCls
			self._slots = SlotsCls(self._core, self._cmd_group)
		return self._slots

	def set(self, carrierComponent=repcap.CarrierComponent.Default, frame=repcap.Frame.Default, bwPart=repcap.BwPart.Default, slot=repcap.Slot.Default) -> None:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:FRAMe<fr>:BWPart<bwp>:SLOT<sl>:PASTe:TO \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.frame.bwPart.slot.paste.to.set(carrierComponent = repcap.CarrierComponent.Default, frame = repcap.Frame.Default, bwPart = repcap.BwPart.Default, slot = repcap.Slot.Default) \n
		This command copies a slot configuration to other slots.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- A slot configuration is in the clipboard (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.Frame.BwPart.Slot.copy) .
			- Number of configurable slots > 1 (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.Frame.BwPart.Cslot.set) .
			- Select custom paste mode (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.Frame.BwPart.Slot.Paste.To.Mode.set) . \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param bwPart: optional repeated capability selector. Default value: Nr1 (settable in the interface 'BwPart')
			:param slot: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
		"""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
		bwPart_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPart, repcap.BwPart)
		slot_cmd_val = self._cmd_group.get_repcap_cmd_value(slot, repcap.Slot)
		self._core.io.write(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:FRAMe{frame_cmd_val}:BWPart{bwPart_cmd_val}:SLOT{slot_cmd_val}:PASTe:TO')

	def set_with_opc(self, carrierComponent=repcap.CarrierComponent.Default, frame=repcap.Frame.Default, bwPart=repcap.BwPart.Default, slot=repcap.Slot.Default, opc_timeout_ms: int = -1) -> None:
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
		bwPart_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPart, repcap.BwPart)
		slot_cmd_val = self._cmd_group.get_repcap_cmd_value(slot, repcap.Slot)
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:FRAMe<fr>:BWPart<bwp>:SLOT<sl>:PASTe:TO \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.frame.bwPart.slot.paste.to.set_with_opc(carrierComponent = repcap.CarrierComponent.Default, frame = repcap.Frame.Default, bwPart = repcap.BwPart.Default, slot = repcap.Slot.Default) \n
		This command copies a slot configuration to other slots.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- A slot configuration is in the clipboard (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.Frame.BwPart.Slot.copy) .
			- Number of configurable slots > 1 (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.Frame.BwPart.Cslot.set) .
			- Select custom paste mode (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.Frame.BwPart.Slot.Paste.To.Mode.set) . \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param bwPart: optional repeated capability selector. Default value: Nr1 (settable in the interface 'BwPart')
			:param slot: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:FRAMe{frame_cmd_val}:BWPart{bwPart_cmd_val}:SLOT{slot_cmd_val}:PASTe:TO', opc_timeout_ms)

	def clone(self) -> 'ToCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ToCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..............Internal.Core import Core
from ..............Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DciSettingsCls:
	"""DciSettings commands group definition. 6 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dciSettings", core, parent)

	@property
	def fdrAssign(self):
		"""fdrAssign commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fdrAssign'):
			from .FdrAssign import FdrAssignCls
			self._fdrAssign = FdrAssignCls(self._core, self._cmd_group)
		return self._fdrAssign

	@property
	def item(self):
		"""item commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_item'):
			from .Item import ItemCls
			self._item = ItemCls(self._core, self._cmd_group)
		return self._item

	@property
	def listPy(self):
		"""listPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_listPy'):
			from .ListPy import ListPyCls
			self._listPy = ListPyCls(self._core, self._cmd_group)
		return self._listPy

	@property
	def noBlock(self):
		"""noBlock commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_noBlock'):
			from .NoBlock import NoBlockCls
			self._noBlock = NoBlockCls(self._core, self._cmd_group)
		return self._noBlock

	@property
	def scope(self):
		"""scope commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scope'):
			from .Scope import ScopeCls
			self._scope = ScopeCls(self._core, self._cmd_group)
		return self._scope

	@property
	def tpcCommand(self):
		"""tpcCommand commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tpcCommand'):
			from .TpcCommand import TpcCommandCls
			self._tpcCommand = TpcCommandCls(self._core, self._cmd_group)
		return self._tpcCommand

	def clone(self) -> 'DciSettingsCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DciSettingsCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SlopeCls:
	"""Slope commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("slope", core, parent)

	def set(self, edge: enums.SlopeType, powerMeter=repcap.PowerMeter.Default) -> None:
		"""SCPI: [SENSe]:PMETer<p>:TRIGger:SLOPe \n
		Snippet: driver.applications.k10Xlte.sense.pmeter.trigger.slope.set(edge = enums.SlopeType.NEGative, powerMeter = repcap.PowerMeter.Default) \n
		No command help available \n
			:param edge: No help available
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
		"""
		param = Conversions.enum_scalar_to_str(edge, enums.SlopeType)
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		self._core.io.write(f'SENSe:PMETer{powerMeter_cmd_val}:TRIGger:SLOPe {param}')

	# noinspection PyTypeChecker
	def get(self, powerMeter=repcap.PowerMeter.Default) -> enums.SlopeType:
		"""SCPI: [SENSe]:PMETer<p>:TRIGger:SLOPe \n
		Snippet: value: enums.SlopeType = driver.applications.k10Xlte.sense.pmeter.trigger.slope.get(powerMeter = repcap.PowerMeter.Default) \n
		No command help available \n
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
			:return: edge: No help available"""
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		response = self._core.io.query_str(f'SENSe:PMETer{powerMeter_cmd_val}:TRIGger:SLOPe?')
		return Conversions.str_to_scalar_enum(response, enums.SlopeType)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class InsertCls:
	"""Insert commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("insert", core, parent)

	def set(self, file_path: str, fileList=repcap.FileList.Default) -> None:
		"""SCPI: [SENSe]:CORRection:FRESponse:USER:FLISt<fli>:INSert \n
		Snippet: driver.sense.correction.fresponse.user.flist.insert.set(file_path = '1', fileList = repcap.FileList.Default) \n
		Loads a frequency response (.fres) file to the current configuration. The maximum number of files per configuration is 15.
		The new file is added below the entry specified by the <fli> index. All other entries with a higher suffix are moved down
		by one position. \n
			:param file_path: string Path and file name The default directory for .fres files is C:/R_S/INSTR/USER/Fresponse.
			:param fileList: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Flist')
		"""
		param = Conversions.value_to_quoted_str(file_path)
		fileList_cmd_val = self._cmd_group.get_repcap_cmd_value(fileList, repcap.FileList)
		self._core.io.write(f'SENSe:CORRection:FRESponse:USER:FLISt{fileList_cmd_val}:INSert {param}')

	def get(self, fileList=repcap.FileList.Default) -> str:
		"""SCPI: [SENSe]:CORRection:FRESponse:USER:FLISt<fli>:INSert \n
		Snippet: value: str = driver.sense.correction.fresponse.user.flist.insert.get(fileList = repcap.FileList.Default) \n
		Loads a frequency response (.fres) file to the current configuration. The maximum number of files per configuration is 15.
		The new file is added below the entry specified by the <fli> index. All other entries with a higher suffix are moved down
		by one position. \n
			:param fileList: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Flist')
			:return: file_path: string Path and file name The default directory for .fres files is C:/R_S/INSTR/USER/Fresponse."""
		fileList_cmd_val = self._cmd_group.get_repcap_cmd_value(fileList, repcap.FileList)
		response = self._core.io.query_str(f'SENSe:CORRection:FRESponse:USER:FLISt{fileList_cmd_val}:INSert?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImmediateCls:
	"""Immediate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("immediate", core, parent)

	def set(self, peaks: float, window=repcap.Window.Default, marker=repcap.Marker.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:FPEaks[:IMMediate] \n
		Snippet: driver.calculate.marker.function.fpeaks.immediate.set(peaks = 1.0, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command initiates a peak search. \n
			:param peaks: This parameter defines the number of peaks to find during the search. Note that the actual number of peaks found during the search also depends on the peak excursion you have set with method RsFsw.Applications.K10x_Lte.Calculate.Marker.Pexcursion.set. Range: 1 to 200
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
		"""
		param = Conversions.decimal_value_to_str(peaks)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		self._core.io.write(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:FPEaks:IMMediate {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PathCls:
	"""Path commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("path", core, parent)

	def set(self, filename: str, demod_bw: float = None) -> None:
		"""SCPI: INPut:FILE:PATH \n
		Snippet: driver.applications.k10Xlte.inputPy.file.path.set(filename = '1', demod_bw = 1.0) \n
		This command selects the I/Q data file to be used as input for further measurements.
			INTRO_CMD_HELP: The I/Q data file must be in one of the following supported formats: \n
			- .iq.tar
			- .iqw
			- .csv
			- .mat
			- .wv
			- .aid
		Only a single data stream or channel can be used as input, even if multiple streams or channels are stored in the file.
		For some file formats that do not provide the sample rate and measurement time or record length, you must define these
		parameters manually. Otherwise the traces are not visible in the result displays. For details, see 'Basics on Input from
		I/Q Data Files'. \n
			:param filename: String containing the path and name of the source file. The file extension is *.iq.tar.
			:param demod_bw: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('filename', filename, DataType.String), ArgSingle('demod_bw', demod_bw, DataType.Float, None, is_optional=True))
		self._core.io.write(f'INPut:FILE:PATH {param}'.rstrip())

	# noinspection PyTypeChecker
	class PathStruct(StructBase):
		"""Response structure. Fields: \n
			- Filename: str: String containing the path and name of the source file. The file extension is *.iq.tar.
			- Demod_Bw: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_str('Filename'),
			ArgStruct.scalar_float('Demod_Bw')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Filename: str = None
			self.Demod_Bw: float = None

	def get(self) -> PathStruct:
		"""SCPI: INPut:FILE:PATH \n
		Snippet: value: PathStruct = driver.applications.k10Xlte.inputPy.file.path.get() \n
		This command selects the I/Q data file to be used as input for further measurements.
			INTRO_CMD_HELP: The I/Q data file must be in one of the following supported formats: \n
			- .iq.tar
			- .iqw
			- .csv
			- .mat
			- .wv
			- .aid
		Only a single data stream or channel can be used as input, even if multiple streams or channels are stored in the file.
		For some file formats that do not provide the sample rate and measurement time or record length, you must define these
		parameters manually. Otherwise the traces are not visible in the result displays. For details, see 'Basics on Input from
		I/Q Data Files'. \n
			:return: structure: for return value, see the help for PathStruct structure arguments."""
		return self._core.io.query_struct(f'INPut:FILE:PATH?', self.__class__.PathStruct())



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RtoCls:
	"""Rto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rto", core, parent)

	def set(self, reference: enums.SyncSignalOffsetReference, carrierComponent=repcap.CarrierComponent.Default) -> None:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:SSBLock:RTO \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.ssBlock.rto.set(reference = enums.SyncSignalOffsetReference.RPA, carrierComponent = repcap.CarrierComponent.Default) \n
		This command selects the reference point for a synchronization signal offset.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- For selection of TxBW: Use at least one bandwidth part that has the same subcarrier spacing as the synchronization signal. For subcarrier spacing = 240 kHz, TxBW is not supported. \n
			:param reference: RPA Offset relative to the reference point A. TXBW Offset relative to the the first subcarrier.
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
		"""
		param = Conversions.enum_scalar_to_str(reference, enums.SyncSignalOffsetReference)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		self._core.io.write(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:SSBLock:RTO {param}')

	# noinspection PyTypeChecker
	def get(self, carrierComponent=repcap.CarrierComponent.Default) -> enums.SyncSignalOffsetReference:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:SSBLock:RTO \n
		Snippet: value: enums.SyncSignalOffsetReference = driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.ssBlock.rto.get(carrierComponent = repcap.CarrierComponent.Default) \n
		This command selects the reference point for a synchronization signal offset.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- For selection of TxBW: Use at least one bandwidth part that has the same subcarrier spacing as the synchronization signal. For subcarrier spacing = 240 kHz, TxBW is not supported. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:return: reference: RPA Offset relative to the reference point A. TXBW Offset relative to the the first subcarrier."""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		response = self._core.io.query_str(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:SSBLock:RTO?')
		return Conversions.str_to_scalar_enum(response, enums.SyncSignalOffsetReference)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TableCls:
	"""Table commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("table", core, parent)

	@property
	def item(self):
		"""item commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_item'):
			from .Item import ItemCls
			self._item = ItemCls(self._core, self._cmd_group)
		return self._item

	def set(self, state: bool, window=repcap.Window.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>]:TABLe \n
		Snippet: driver.applications.k91Wlan.display.window.table.set(state = False, window = repcap.Window.Default) \n
		Displays or removes the 'Result Summary' Global window. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Removes the 'Result Summary' Global window ON | 1 Displays the 'Result Summary' Global window
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:TABLe {param}')

	def get(self, window=repcap.Window.Default) -> bool:
		"""SCPI: DISPlay[:WINDow<n>]:TABLe \n
		Snippet: value: bool = driver.applications.k91Wlan.display.window.table.get(window = repcap.Window.Default) \n
		Displays or removes the 'Result Summary' Global window. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:return: state: ON | OFF | 0 | 1 OFF | 0 Removes the 'Result Summary' Global window ON | 1 Displays the 'Result Summary' Global window"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:TABLe?')
		return Conversions.str_to_bool(response)

	def clone(self) -> 'TableCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TableCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.MarkerMode, window=repcap.Window.Default, marker=repcap.Marker.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:BPOWer:MODE \n
		Snippet: driver.calculate.marker.function.bpower.mode.set(mode = enums.MarkerMode.DENSity, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command selects the way the results for a band power marker are displayed. (Note: relative power results are only
		availabe for delta markers, see .method RsFsw.Calculate.DeltaMarker.Function.Bpower.Mode.set \n
			:param mode: POWer Result is displayed as an absolute power. The power unit depends on the method RsFsw.Applications.K91_Wlan.Calculate.Unit.Power.set setting. DENSity Result is displayed as a density in dBm/Hz.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.MarkerMode)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		self._core.io.write(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:BPOWer:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> enums.MarkerMode:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:BPOWer:MODE \n
		Snippet: value: enums.MarkerMode = driver.calculate.marker.function.bpower.mode.get(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command selects the way the results for a band power marker are displayed. (Note: relative power results are only
		availabe for delta markers, see .method RsFsw.Calculate.DeltaMarker.Function.Bpower.Mode.set \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: mode: POWer Result is displayed as an absolute power. The power unit depends on the method RsFsw.Applications.K91_Wlan.Calculate.Unit.Power.set setting. DENSity Result is displayed as a density in dBm/Hz."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:BPOWer:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.MarkerMode)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.Types import DataType
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, trace_1: enums.TraceModeA, trace_2: enums.TraceModeA, trace_3: enums.TraceModeA) -> None:
		"""SCPI: [SENSe]:ADEMod:SPECtrum:PHASe:TYPE \n
		Snippet: driver.applications.k17Mcgd.sense.ademod.spectrum.phase.typePy.set(trace_1 = enums.TraceModeA.AVERage, trace_2 = enums.TraceModeA.AVERage, trace_3 = enums.TraceModeA.AVERage) \n
		This command sets the modes of the first three traces of phase windows. Note that this command is maintained for
		compatibility reasons only. Use method RsFsw.Display.Window.Subwindow.Trace.Mode.set for new remote control programs. \n
			:param trace_1: WRITe | AVERage | MINHold | MAXHold | VIEW | OFF
			:param trace_2: WRITe | AVERage | MINHold | MAXHold | VIEW | OFF
			:param trace_3: WRITe | AVERage | MINHold | MAXHold | VIEW | OFF
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('trace_1', trace_1, DataType.Enum, enums.TraceModeA), ArgSingle('trace_2', trace_2, DataType.Enum, enums.TraceModeA), ArgSingle('trace_3', trace_3, DataType.Enum, enums.TraceModeA))
		self._core.io.write(f'SENSe:ADEMod:SPECtrum:PHASe:TYPE {param}'.rstrip())

	# noinspection PyTypeChecker
	class TypePyStruct(StructBase):
		"""Response structure. Fields: \n
			- Trace_1: enums.TraceModeA: WRITe | AVERage | MINHold | MAXHold | VIEW | OFF
			- Trace_2: enums.TraceModeA: WRITe | AVERage | MINHold | MAXHold | VIEW | OFF
			- Trace_3: enums.TraceModeA: WRITe | AVERage | MINHold | MAXHold | VIEW | OFF"""
		__meta_args_list = [
			ArgStruct.scalar_enum('Trace_1', enums.TraceModeA),
			ArgStruct.scalar_enum('Trace_2', enums.TraceModeA),
			ArgStruct.scalar_enum('Trace_3', enums.TraceModeA)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Trace_1: enums.TraceModeA = None
			self.Trace_2: enums.TraceModeA = None
			self.Trace_3: enums.TraceModeA = None

	def get(self) -> TypePyStruct:
		"""SCPI: [SENSe]:ADEMod:SPECtrum:PHASe:TYPE \n
		Snippet: value: TypePyStruct = driver.applications.k17Mcgd.sense.ademod.spectrum.phase.typePy.get() \n
		This command sets the modes of the first three traces of phase windows. Note that this command is maintained for
		compatibility reasons only. Use method RsFsw.Display.Window.Subwindow.Trace.Mode.set for new remote control programs. \n
			:return: structure: for return value, see the help for TypePyStruct structure arguments."""
		return self._core.io.query_struct(f'SENSe:ADEMod:SPECtrum:PHASe:TYPE?', self.__class__.TypePyStruct())



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal.Utilities import trim_str_response
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultCls:
	"""Result commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("result", core, parent)

	@property
	def absolute(self):
		"""absolute commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_absolute'):
			from .Absolute import AbsoluteCls
			self._absolute = AbsoluteCls(self._core, self._cmd_group)
		return self._absolute

	@property
	def relative(self):
		"""relative commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_relative'):
			from .Relative import RelativeCls
			self._relative = RelativeCls(self._core, self._cmd_group)
		return self._relative

	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, gapChannel=repcap.GapChannel.Default) -> str:
		"""SCPI: CALCulate<n>:LIMit<li>:ACPower:GAP<gap>[:CACLr]:RESult \n
		Snippet: value: str = driver.applications.k14Xnr5G.calculate.limit.acPower.gap.caclr.result.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default, gapChannel = repcap.GapChannel.Default) \n
		This command queries the limit check results for the gap channels (MC ACLR measurements) . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
			:return: limit_check: Returns two values, one for the upper and one for the lower adjacent channel. PASSED Limit check has passed. FAILED Limit check has failed."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:ACPower:GAP{gapChannel_cmd_val}:CACLr:RESult?')
		return trim_str_response(response)

	def clone(self) -> 'ResultCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ResultCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CselectCls:
	"""Cselect commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cselect", core, parent)

	def set(self, channel_type: enums.ChannelTypeResults) -> None:
		"""SCPI: CONFigure:BURSt:SPECtrum:FLATness:CSELect \n
		Snippet: driver.applications.k91Wlan.configure.burst.spectrum.flatness.cselect.set(channel_type = enums.ChannelTypeResults.EFFective) \n
		This remote control command configures the 'Spectrum Flatness' and 'Group Delay' results to be based on either effective
		or physical channels. This command is only valid for IEEE 802.11n and IEEE 802.11ac standards. While the physical
		channels cannot always be determined, the effective channel can always be estimated from the known training fields. Thus,
		for some PPDUs or measurement scenarios, only the results based on the mapping of the space-time stream to the Rx antenna
		(effective channel) are available, as the mapping of the Rx antennas to the Tx antennas (physical channel) could not be
		determined. For more information see 'Physical vs effective channels'. \n
			:param channel_type: EFFective | PHYSical
		"""
		param = Conversions.enum_scalar_to_str(channel_type, enums.ChannelTypeResults)
		self._core.io.write(f'CONFigure:BURSt:SPECtrum:FLATness:CSELect {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.ChannelTypeResults:
		"""SCPI: CONFigure:BURSt:SPECtrum:FLATness:CSELect \n
		Snippet: value: enums.ChannelTypeResults = driver.applications.k91Wlan.configure.burst.spectrum.flatness.cselect.get() \n
		This remote control command configures the 'Spectrum Flatness' and 'Group Delay' results to be based on either effective
		or physical channels. This command is only valid for IEEE 802.11n and IEEE 802.11ac standards. While the physical
		channels cannot always be determined, the effective channel can always be estimated from the known training fields. Thus,
		for some PPDUs or measurement scenarios, only the results based on the mapping of the space-time stream to the Rx antenna
		(effective channel) are available, as the mapping of the Rx antennas to the Tx antennas (physical channel) could not be
		determined. For more information see 'Physical vs effective channels'. \n
			:return: channel_type: EFFective | PHYSical"""
		response = self._core.io.query_str(f'CONFigure:BURSt:SPECtrum:FLATness:CSELect?')
		return Conversions.str_to_scalar_enum(response, enums.ChannelTypeResults)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FunctionCls:
	"""Function commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("function", core, parent)

	def set(self, function: enums.FunctionA, subBlock=repcap.SubBlock.Default, rangePy=repcap.RangePy.Default, limitIx=repcap.LimitIx.Default) -> None:
		"""SCPI: [SENSe]:ESPectrum<sb>:RANGe<ri>:LIMit<li>:RELative:STARt:FUNCtion \n
		Snippet: driver.sense.espectrum.range.limit.relative.start.function.set(function = enums.FunctionA.MAX, subBlock = repcap.SubBlock.Default, rangePy = repcap.RangePy.Default, limitIx = repcap.LimitIx.Default) \n
		No command help available \n
			:param function: OFF | MAX Defines the function to be used to determine the relative limit line start value MAX The maximum of the relative and the absolute level is used as the limit start value. Use the [SENSe:]ESPectrumsb:RANGeri:LIMitli:RELative:STARt and [SENSe:]ESPectrumsb:RANGeri:LIMitli:RELative:STARt:ABS commands to define these values. OFF No function is used, the relative limit line is defined by a fixed relative start value. Use the [SENSe:]ESPectrumsb:RANGeri:LIMitli:RELative:STARtcommand to define this value.
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
		"""
		param = Conversions.enum_scalar_to_str(function, enums.FunctionA)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		self._core.io.write(f'SENSe:ESPectrum{subBlock_cmd_val}:RANGe{rangePy_cmd_val}:LIMit{limitIx_cmd_val}:RELative:STARt:FUNCtion {param}')

	# noinspection PyTypeChecker
	def get(self, subBlock=repcap.SubBlock.Default, rangePy=repcap.RangePy.Default, limitIx=repcap.LimitIx.Default) -> enums.FunctionA:
		"""SCPI: [SENSe]:ESPectrum<sb>:RANGe<ri>:LIMit<li>:RELative:STARt:FUNCtion \n
		Snippet: value: enums.FunctionA = driver.sense.espectrum.range.limit.relative.start.function.get(subBlock = repcap.SubBlock.Default, rangePy = repcap.RangePy.Default, limitIx = repcap.LimitIx.Default) \n
		No command help available \n
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:return: function: OFF | MAX Defines the function to be used to determine the relative limit line start value MAX The maximum of the relative and the absolute level is used as the limit start value. Use the [SENSe:]ESPectrumsb:RANGeri:LIMitli:RELative:STARt and [SENSe:]ESPectrumsb:RANGeri:LIMitli:RELative:STARt:ABS commands to define these values. OFF No function is used, the relative limit line is defined by a fixed relative start value. Use the [SENSe:]ESPectrumsb:RANGeri:LIMitli:RELative:STARtcommand to define this value."""
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		response = self._core.io.query_str(f'SENSe:ESPectrum{subBlock_cmd_val}:RANGe{rangePy_cmd_val}:LIMit{limitIx_cmd_val}:RELative:STARt:FUNCtion?')
		return Conversions.str_to_scalar_enum(response, enums.FunctionA)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MvelocityCls:
	"""Mvelocity commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mvelocity", core, parent)

	def set(self, max_rel_velocity: float) -> None:
		"""SCPI: [SENSe]:CESTimation:MVELocity \n
		Snippet: driver.applications.k17Mcgd.sense.cestimation.mvelocity.set(max_rel_velocity = 1.0) \n
		Defines the relative velocity between ground station and satellite in m/s. This information is used to calculate the Max
		Clock Offset. \n
			:param max_rel_velocity: numeric value Unit: m/s
		"""
		param = Conversions.decimal_value_to_str(max_rel_velocity)
		self._core.io.write(f'SENSe:CESTimation:MVELocity {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:CESTimation:MVELocity \n
		Snippet: value: float = driver.applications.k17Mcgd.sense.cestimation.mvelocity.get() \n
		Defines the relative velocity between ground station and satellite in m/s. This information is used to calculate the Max
		Clock Offset. \n
			:return: max_rel_velocity: numeric value Unit: m/s"""
		response = self._core.io.query_str(f'SENSe:CESTimation:MVELocity?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class WlanCls:
	"""Wlan commands group definition. 49 total commands, 11 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("wlan", core, parent)

	@property
	def mimo(self):
		"""mimo commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_mimo'):
			from .Mimo import MimoCls
			self._mimo = MimoCls(self._core, self._cmd_group)
		return self._mimo

	@property
	def dutConfig(self):
		"""dutConfig commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dutConfig'):
			from .DutConfig import DutConfigCls
			self._dutConfig = DutConfigCls(self._core, self._cmd_group)
		return self._dutConfig

	@property
	def antMatrix(self):
		"""antMatrix commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_antMatrix'):
			from .AntMatrix import AntMatrixCls
			self._antMatrix = AntMatrixCls(self._core, self._cmd_group)
		return self._antMatrix

	@property
	def gtime(self):
		"""gtime commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_gtime'):
			from .Gtime import GtimeCls
			self._gtime = GtimeCls(self._core, self._cmd_group)
		return self._gtime

	@property
	def ruConfig(self):
		"""ruConfig commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_ruConfig'):
			from .RuConfig import RuConfigCls
			self._ruConfig = RuConfigCls(self._core, self._cmd_group)
		return self._ruConfig

	@property
	def rsync(self):
		"""rsync commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_rsync'):
			from .Rsync import RsyncCls
			self._rsync = RsyncCls(self._core, self._cmd_group)
		return self._rsync

	@property
	def stbc(self):
		"""stbc commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_stbc'):
			from .Stbc import StbcCls
			self._stbc = StbcCls(self._core, self._cmd_group)
		return self._stbc

	@property
	def extension(self):
		"""extension commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_extension'):
			from .Extension import ExtensionCls
			self._extension = ExtensionCls(self._core, self._cmd_group)
		return self._extension

	@property
	def smapping(self):
		"""smapping commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_smapping'):
			from .Smapping import SmappingCls
			self._smapping = SmappingCls(self._core, self._cmd_group)
		return self._smapping

	@property
	def payload(self):
		"""payload commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_payload'):
			from .Payload import PayloadCls
			self._payload = PayloadCls(self._core, self._cmd_group)
		return self._payload

	@property
	def pvError(self):
		"""pvError commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pvError'):
			from .PvError import PvErrorCls
			self._pvError = PvErrorCls(self._core, self._cmd_group)
		return self._pvError

	def clone(self) -> 'WlanCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = WlanCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, err_type: enums.ErrorType) -> None:
		"""SCPI: CONFigure:BURSt:PREamble:SELect \n
		Snippet: driver.applications.k91Wlan.configure.burst.preamble.select.set(err_type = enums.ErrorType.FREQuency) \n
		This remote control command specifies whether frequency or phase results are displayed when the measurement type is set
		to 'Error Vs Preamble' (method RsFsw.Applications.K91_Wlan.Configure.Burst.Preamble.Immediate.set) . \n
			:param err_type: FREQuency | PHASe FREQuency Displays frequency error results for the preamble of the measured PPDUs only PHASe Displays phase error results for the preamble of the measured PPDUs only
		"""
		param = Conversions.enum_scalar_to_str(err_type, enums.ErrorType)
		self._core.io.write(f'CONFigure:BURSt:PREamble:SELect {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.ErrorType:
		"""SCPI: CONFigure:BURSt:PREamble:SELect \n
		Snippet: value: enums.ErrorType = driver.applications.k91Wlan.configure.burst.preamble.select.get() \n
		This remote control command specifies whether frequency or phase results are displayed when the measurement type is set
		to 'Error Vs Preamble' (method RsFsw.Applications.K91_Wlan.Configure.Burst.Preamble.Immediate.set) . \n
			:return: err_type: FREQuency | PHASe FREQuency Displays frequency error results for the preamble of the measured PPDUs only PHASe Displays phase error results for the preamble of the measured PPDUs only"""
		response = self._core.io.query_str(f'CONFigure:BURSt:PREamble:SELect?')
		return Conversions.str_to_scalar_enum(response, enums.ErrorType)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BinsCls:
	"""Bins commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bins", core, parent)

	def set(self, bins: float, window=repcap.Window.Default) -> None:
		"""SCPI: SENSe[:WINDow<n>]:DISPlay:CONFig:BINS \n
		Snippet: driver.applications.k149Uwb.sense.window.display.config.bins.set(bins = 1.0, window = repcap.Window.Default) \n
		Sets the number of bins for the histogram trace results. \n
			:param bins: numeric value
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
		"""
		param = Conversions.decimal_value_to_str(bins)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'SENSe:WINDow{window_cmd_val}:DISPlay:CONFig:BINS {param}')

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: SENSe[:WINDow<n>]:DISPlay:CONFig:BINS \n
		Snippet: value: float = driver.applications.k149Uwb.sense.window.display.config.bins.get(window = repcap.Window.Default) \n
		Sets the number of bins for the histogram trace results. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:return: bins: numeric value"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'SENSe:WINDow{window_cmd_val}:DISPlay:CONFig:BINS?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BandCls:
	"""Band commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("band", core, parent)

	def preset(self) -> None:
		"""SCPI: [SENSe]:MIXer:HARMonic:BAND:PRESet \n
		Snippet: driver.applications.k70Vsa.sense.mixer.harmonic.band.preset() \n
		This command restores the preset frequency ranges for the selected standard waveguide band. Note:Changes to the band and
		mixer settings are maintained even after using the [PRESET] function. Use this command to restore the predefined band
		ranges. \n
		"""
		self._core.io.write(f'SENSe:MIXer:HARMonic:BAND:PRESet')

	def preset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SENSe]:MIXer:HARMonic:BAND:PRESet \n
		Snippet: driver.applications.k70Vsa.sense.mixer.harmonic.band.preset_with_opc() \n
		This command restores the preset frequency ranges for the selected standard waveguide band. Note:Changes to the band and
		mixer settings are maintained even after using the [PRESET] function. Use this command to restore the predefined band
		ranges. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:MIXer:HARMonic:BAND:PRESet', opc_timeout_ms)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, mode: enums.PvTmode) -> None:
		"""SCPI: CONFigure:BURSt:PVT:SELect \n
		Snippet: driver.applications.k91Wlan.configure.burst.pvt.select.set(mode = enums.PvTmode.EDGE) \n
		This remote command determines how to interpret the 'Power vs Time' measurement results. \n
			:param mode: EDGE | FULL | RISE | FALL EDGE Displays rising and falling edges only FALL Displays falling edge only FULL Displays the full PPDU RISE Displays the rising edge only
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.PvTmode)
		self._core.io.write(f'CONFigure:BURSt:PVT:SELect {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.PvTmode:
		"""SCPI: CONFigure:BURSt:PVT:SELect \n
		Snippet: value: enums.PvTmode = driver.applications.k91Wlan.configure.burst.pvt.select.get() \n
		This remote command determines how to interpret the 'Power vs Time' measurement results. \n
			:return: mode: EDGE | FULL | RISE | FALL EDGE Displays rising and falling edges only FALL Displays falling edge only FULL Displays the full PPDU RISE Displays the rising edge only"""
		response = self._core.io.query_str(f'CONFigure:BURSt:PVT:SELect?')
		return Conversions.str_to_scalar_enum(response, enums.PvTmode)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TextCls:
	"""Text commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("text", core, parent)

	def set(self, message: str) -> None:
		"""SCPI: SYSTem:DISPlay:MESSage[:TEXT] \n
		Snippet: driver.system.display.message.text.set(message = '1') \n
		No command help available \n
			:param message: No help available
		"""
		param = Conversions.value_to_quoted_str(message)
		self._core.io.write(f'SYSTem:DISPlay:MESSage:TEXT {param}')

	def get(self) -> str:
		"""SCPI: SYSTem:DISPlay:MESSage[:TEXT] \n
		Snippet: value: str = driver.system.display.message.text.get() \n
		No command help available \n
			:return: message: No help available"""
		response = self._core.io.query_str(f'SYSTem:DISPlay:MESSage:TEXT?')
		return trim_str_response(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BwCls:
	"""Bw commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bw", core, parent)

	def set(self, bandwidth: enums.BandwidthNr5G, carrierComponent=repcap.CarrierComponent.Default) -> None:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:BW \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.bw.set(bandwidth = enums.BandwidthNr5G.BW10, carrierComponent = repcap.CarrierComponent.Default) \n
		This command selects the channel bandwidth of the 5G NR carrier. \n
			:param bandwidth: BW5 | BW10 | BW15 | BW20 | BW25 | BW30 | BW35 | BW40 | BW45 | BW50 | BW60 | BW70 | BW80 | BW90 | BW100 | BW200 | BW400 | BW800 | BW1600 | BW2000
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
		"""
		param = Conversions.enum_scalar_to_str(bandwidth, enums.BandwidthNr5G)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		self._core.io.write(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:BW {param}')

	# noinspection PyTypeChecker
	def get(self, carrierComponent=repcap.CarrierComponent.Default) -> enums.BandwidthNr5G:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:BW \n
		Snippet: value: enums.BandwidthNr5G = driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.bw.get(carrierComponent = repcap.CarrierComponent.Default) \n
		This command selects the channel bandwidth of the 5G NR carrier. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:return: bandwidth: BW5 | BW10 | BW15 | BW20 | BW25 | BW30 | BW35 | BW40 | BW45 | BW50 | BW60 | BW70 | BW80 | BW90 | BW100 | BW200 | BW400 | BW800 | BW1600 | BW2000"""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		response = self._core.io.query_str(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:BW?')
		return Conversions.str_to_scalar_enum(response, enums.BandwidthNr5G)



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Types import DataType
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	def set(self, frequency: List[float], level: List[float]) -> None:
		"""SCPI: [SENSe]:CORRection:TRANsducer:DATA \n
		Snippet: driver.sense.correction.transducer.data.set(frequency = [1.1, 2.2, 3.3], level = [1.1, 2.2, 3.3]) \n
		This command configures transducer factors for specific trace points. A set of transducer factors defines an interpolated
		transducer line and can be stored on the instrument. For details see 'Basics on transducer factors'. \n
			:param frequency: The unit for Frequency is Hz, which may or may not be omitted. Frequencies have to be sorted in ascending order. Unit: Hz
			:param level: The unit for Level depends on[SENSe:]CORRection:TRANsducer:UNIT .
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('frequency', frequency, DataType.FloatList, None), ArgSingle.as_open_list('level', level, DataType.FloatList, None))
		self._core.io.write(f'SENSe:CORRection:TRANsducer:DATA {param}'.rstrip())

	# noinspection PyTypeChecker
	class DataStruct(StructBase):
		"""Response structure. Fields: \n
			- Frequency: List[float]: The unit for Frequency is Hz, which may or may not be omitted. Frequencies have to be sorted in ascending order. Unit: Hz
			- Level: List[float]: The unit for Level depends on[SENSe:]CORRection:TRANsducer:UNIT ."""
		__meta_args_list = [
			ArgStruct('Frequency', DataType.FloatList, None, False, True, 1),
			ArgStruct('Level', DataType.FloatList, None, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Frequency: List[float] = None
			self.Level: List[float] = None

	def get(self) -> DataStruct:
		"""SCPI: [SENSe]:CORRection:TRANsducer:DATA \n
		Snippet: value: DataStruct = driver.sense.correction.transducer.data.get() \n
		This command configures transducer factors for specific trace points. A set of transducer factors defines an interpolated
		transducer line and can be stored on the instrument. For details see 'Basics on transducer factors'. \n
			:return: structure: for return value, see the help for DataStruct structure arguments."""
		return self._core.io.query_struct(f'SENSe:CORRection:TRANsducer:DATA?', self.__class__.DataStruct())



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TableCls:
	"""Table commands group definition. 9 total commands, 7 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("table", core, parent)

	@property
	def add(self):
		"""add commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_add'):
			from .Add import AddCls
			self._add = AddCls(self._core, self._cmd_group)
		return self._add

	@property
	def replace(self):
		"""replace commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_replace'):
			from .Replace import ReplaceCls
			self._replace = ReplaceCls(self._core, self._cmd_group)
		return self._replace

	@property
	def start(self):
		"""start commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_start'):
			from .Start import StartCls
			self._start = StartCls(self._core, self._cmd_group)
		return self._start

	@property
	def step(self):
		"""step commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_step'):
			from .Step import StepCls
			self._step = StepCls(self._core, self._cmd_group)
		return self._step

	@property
	def nstates(self):
		"""nstates commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nstates'):
			from .Nstates import NstatesCls
			self._nstates = NstatesCls(self._core, self._cmd_group)
		return self._nstates

	@property
	def tolerance(self):
		"""tolerance commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tolerance'):
			from .Tolerance import ToleranceCls
			self._tolerance = ToleranceCls(self._core, self._cmd_group)
		return self._tolerance

	@property
	def offset(self):
		"""offset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_offset'):
			from .Offset import OffsetCls
			self._offset = OffsetCls(self._core, self._cmd_group)
		return self._offset

	def load(self, filename: str, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:HOPDetection:STATes:TABLe:LOAD \n
		Snippet: driver.applications.k60Transient.calculate.hopDetection.states.table.load(filename = '1', window = repcap.Window.Default) \n
		Loads the signal state table configuration from the selected file. \n
			:param filename: String containing the path and name of the file.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.value_to_quoted_str(filename)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:HOPDetection:STATes:TABLe:LOAD {param}')

	def save(self, filename: str, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:HOPDetection:STATes:TABLe:SAVE \n
		Snippet: driver.applications.k60Transient.calculate.hopDetection.states.table.save(filename = '1', window = repcap.Window.Default) \n
		Saves the current signal state table configuration to a file for later use. \n
			:param filename: String containing the path and name of the file.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.value_to_quoted_str(filename)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:HOPDetection:STATes:TABLe:SAVE {param}')

	def clone(self) -> 'TableCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TableCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CenterCls:
	"""Center commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("center", core, parent)

	@property
	def ledState(self):
		"""ledState commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ledState'):
			from .LedState import LedStateCls
			self._ledState = LedStateCls(self._core, self._cmd_group)
		return self._ledState

	@property
	def sync(self):
		"""sync commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sync'):
			from .Sync import SyncCls
			self._sync = SyncCls(self._core, self._cmd_group)
		return self._sync

	def set(self, frequency: float) -> None:
		"""SCPI: CONFigure:GENerator:FREQuency:CENTer \n
		Snippet: driver.applications.k18AmplifierEt.configure.generator.frequency.center.set(frequency = 1.0) \n
		This command defines the frequency of the generator. Make sure to synchronize with *OPC? or *WAI to make sure that the
		command was successfully applied on the generator before sending the next command. \n
			:param frequency: numeric value Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'CONFigure:GENerator:FREQuency:CENTer {param}')

	def get(self) -> float:
		"""SCPI: CONFigure:GENerator:FREQuency:CENTer \n
		Snippet: value: float = driver.applications.k18AmplifierEt.configure.generator.frequency.center.get() \n
		This command defines the frequency of the generator. Make sure to synchronize with *OPC? or *WAI to make sure that the
		command was successfully applied on the generator before sending the next command. \n
			:return: frequency: numeric value Unit: Hz"""
		response = self._core.io.query_str(f'CONFigure:GENerator:FREQuency:CENTer?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'CenterCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CenterCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultsCls:
	"""Results commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("results", core, parent)

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- Idn: str: char_data Timestamp which corresponds to the absolute time the beginning of the chirp was detected
			- Chirp_No: float: Consecutive number of detected chirp, starts at 1 for each new measurement
			- State_Index: float: Consecutive number of corresponding nominal chirp state as defined in the 'Chirp States' table (see [CMDLINK: CALCulaten:CHRDetection:STATes[:DATA] CMDLINK])
			- Begin: str: char_data Time offset from the analysis region start at which the signal first enters the tolerance area of a nominal chirp Unit: ms
			- Length: str: char_data The duration of a chirp from begin to end, that is, the time the signal remains in the tolerance area of a nominal chirp. Unit: ms
			- Crate: str: char_data Derivative of the FM vs time trace within the frequency measurement range Unit: kHz/μs
			- Crate_Dev: float: Deviation of the detected chirp rate from the nominal chirp state (in kHz/us) . For details see 'Chirp State Deviation'. Unit: kHz/μs
			- Freq_Avg: float: Average frequency measured within the frequency measurement range of the chirp Unit: kHz
			- Fm_Dev_Max: float: Maximum deviation of the chirp frequency from the nominal chirp frequency as defined in the 'Chirp States' table. The deviation is calculated within the frequency measurement range of the chirp. For details see 'Frequency Deviation (Peak) '. Unit: kHz
			- Fm_Dev_Rms: float: RMS deviation of the chirp frequency from the nominal (linear) chirp frequency as defined in the 'Chirp States' table. The deviation is calculated within the frequency measurement range of the chirp. For details see 'Frequency Deviation (RMS) '. Unit: kHz
			- Fm_Dev_Avg: float: Average deviation of the chirp frequency from the nominal (linear) chirp frequency as defined in the 'Chirp States' table. The deviation is calculated within the frequency measurement range of the chirp. For details see 'Frequency Deviation (Average) '. Unit: kHz
			- Pm_Dev_Max: float: Maximum deviation of the chirp phase from the nominal chirp phase as defined in the 'Chirp States' table. The deviation is calculated within the frequency measurement range of the chirp. For details see 'Phase Deviation (Peak) '. Unit: kHz
			- Pm_Dev_Rms: float: RMS deviation of the chirp phase from the nominal (linear) chirp phase as defined in the 'Chirp States' table. The deviation is calculated within the frequency measurement range of the chirp. For details see 'Phase Deviation (RMS) '. Unit: kHz
			- Pm_Dev_Avg: float: Average deviation of the chirp phase from the nominal (linear) chirp phase as defined in the 'Chirp States' table. The deviation is calculated within the frequency measurement range of the chirp. For details see 'Phase Deviation (Average) '. Unit: kHz
			- Pow_Min: float: Minimum power level measured during a chirp. Which part of the chirp precisely is used for calculation depends on the power parameters in the 'Power' measurement range configuration. Unit: dBm
			- Pow_Max: float: Maximum power level measured during a chirp. Which part of the chirp precisely is used for calculation depends on the power parameters in the 'Power' measurement range configuration. Unit: dBm
			- Pow_Avg: float: Average power level measured during a chirp. Which part of the chirp precisely is used for calculation depends on the power parameters in the 'Power' measurement range configuration. Unit: dBm
			- Pow_Rip: float: Power level measured during the chirp ripple time. Which part of the chirp precisely is used for calculation depends on the power parameters in the 'Power' measurement range configuration. Unit: dBm"""
		__meta_args_list = [
			ArgStruct.scalar_raw_str('Idn'),
			ArgStruct.scalar_float('Chirp_No'),
			ArgStruct.scalar_float('State_Index'),
			ArgStruct.scalar_raw_str('Begin'),
			ArgStruct.scalar_raw_str('Length'),
			ArgStruct.scalar_raw_str('Crate'),
			ArgStruct.scalar_float('Crate_Dev'),
			ArgStruct.scalar_float('Freq_Avg'),
			ArgStruct.scalar_float('Fm_Dev_Max'),
			ArgStruct.scalar_float('Fm_Dev_Rms'),
			ArgStruct.scalar_float('Fm_Dev_Avg'),
			ArgStruct.scalar_float('Pm_Dev_Max'),
			ArgStruct.scalar_float('Pm_Dev_Rms'),
			ArgStruct.scalar_float('Pm_Dev_Avg'),
			ArgStruct.scalar_float('Pow_Min'),
			ArgStruct.scalar_float('Pow_Max'),
			ArgStruct.scalar_float('Pow_Avg'),
			ArgStruct.scalar_float('Pow_Rip')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Idn: str = None
			self.Chirp_No: float = None
			self.State_Index: float = None
			self.Begin: str = None
			self.Length: str = None
			self.Crate: str = None
			self.Crate_Dev: float = None
			self.Freq_Avg: float = None
			self.Fm_Dev_Max: float = None
			self.Fm_Dev_Rms: float = None
			self.Fm_Dev_Avg: float = None
			self.Pm_Dev_Max: float = None
			self.Pm_Dev_Rms: float = None
			self.Pm_Dev_Avg: float = None
			self.Pow_Min: float = None
			self.Pow_Max: float = None
			self.Pow_Avg: float = None
			self.Pow_Rip: float = None

	def get(self, start: int = None, end: int = None, window=repcap.Window.Default) -> GetStruct:
		"""SCPI: CALCulate<n>:CHRDetection:TABLe:RESults \n
		Snippet: value: GetStruct = driver.applications.k60Transient.calculate.chrDetection.table.results.get(start = 1, end = 1, window = repcap.Window.Default) \n
		This command queries the chirp results table. The result is a comma-separated list of value sets, one set for each chirp.
		If no query parameters are specified, the results for all detected chirps are returned. Which values are returned depends
		on the enabled parameters for the results tables (see method RsFsw.Applications.K60_Transient.Calculate.ChrDetection.
		Table.Column.set) . \n
			:param start: integer The chirp number of the first chirp to be returned. Chirp numbers start at 1.
			:param end: integer The chirp number of the last chirp to be returned.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		param = ArgSingleList().compose_cmd_string(ArgSingle('start', start, DataType.Integer, None, is_optional=True), ArgSingle('end', end, DataType.Integer, None, is_optional=True))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		return self._core.io.query_struct(f'CALCulate{window_cmd_val}:CHRDetection:TABLe:RESults? {param}'.rstrip(), self.__class__.GetStruct())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LoadCls:
	"""Load commands group definition. 10 total commands, 5 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("load", core, parent)

	@property
	def demodSetting(self):
		"""demodSetting commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_demodSetting'):
			from .DemodSetting import DemodSettingCls
			self._demodSetting = DemodSettingCls(self._core, self._cmd_group)
		return self._demodSetting

	@property
	def iq(self):
		"""iq commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_iq'):
			from .Iq import IqCls
			self._iq = IqCls(self._core, self._cmd_group)
		return self._iq

	@property
	def limit(self):
		"""limit commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_limit'):
			from .Limit import LimitCls
			self._limit = LimitCls(self._core, self._cmd_group)
		return self._limit

	@property
	def settings(self):
		"""settings commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_settings'):
			from .Settings import SettingsCls
			self._settings = SettingsCls(self._core, self._cmd_group)
		return self._settings

	@property
	def tmodel(self):
		"""tmodel commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_tmodel'):
			from .Tmodel import TmodelCls
			self._tmodel = TmodelCls(self._core, self._cmd_group)
		return self._tmodel

	def clone(self) -> 'LoadCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LoadCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EcmGainCls:
	"""EcmGain commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ecmGain", core, parent)

	def get(self) -> str:
		"""SCPI: FETCh:BURSt:ECMGain \n
		Snippet: value: str = driver.applications.k91Wlan.fetch.burst.ecmGain.get() \n
		This command returns the effective channel gain result which is used as the reference for the 'Spectrum Flatness' limits
		when 'Spectrum Flatness' results are based on effective channels (see method RsFsw.Applications.K91_Wlan.Configure.Burst.
		Spectrum.Flatness.Cselect.set) . For details see 'Modulation accuracy, flatness and tolerance parameters'. \n
			:return: result: comma-separated list of values; one value for each RX stream Unit: dBm"""
		response = self._core.io.query_str(f'FETCh:BURSt:ECMGain?')
		return trim_str_response(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class VdeviceCls:
	"""Vdevice commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("vdevice", core, parent)

	def set(self, valid_device: bool) -> None:
		"""SCPI: SYSTem:COMMunicate:RDEVice:OSCilloscope:VDEVice \n
		Snippet: driver.applications.k18AmplifierEt.system.communicate.rdevice.oscilloscope.vdevice.set(valid_device = False) \n
		No command help available \n
			:param valid_device: No help available
		"""
		param = Conversions.bool_to_str(valid_device)
		self._core.io.write(f'SYSTem:COMMunicate:RDEVice:OSCilloscope:VDEVice {param}')

	def get(self) -> bool:
		"""SCPI: SYSTem:COMMunicate:RDEVice:OSCilloscope:VDEVice \n
		Snippet: value: bool = driver.applications.k18AmplifierEt.system.communicate.rdevice.oscilloscope.vdevice.get() \n
		No command help available \n
			:return: valid_device: No help available"""
		response = self._core.io.query_str(f'SYSTem:COMMunicate:RDEVice:OSCilloscope:VDEVice?')
		return Conversions.str_to_bool(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, gapChannel=repcap.GapChannel.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit<li>:ACPower:GAP<gap>[:AUTO]:ACLR[:RELative]:STATe \n
		Snippet: driver.calculate.limit.acPower.gap.auto.aclr.relative.state.set(state = False, window = repcap.Window.Default, limitIx = repcap.LimitIx.Default, gapChannel = repcap.GapChannel.Default) \n
		This command turns the relative limit check for the specified gap (CACLR) channel on and off. You have to activate the
		general ACLR limit check before using this command with method RsFsw.Calculate.Limit.AcPower.State.set. \n
			:param state: ON | OFF | 1 | 0
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:ACPower:GAP{gapChannel_cmd_val}:AUTO:ACLR:RELative:STATe {param}')

	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, gapChannel=repcap.GapChannel.Default) -> bool:
		"""SCPI: CALCulate<n>:LIMit<li>:ACPower:GAP<gap>[:AUTO]:ACLR[:RELative]:STATe \n
		Snippet: value: bool = driver.calculate.limit.acPower.gap.auto.aclr.relative.state.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default, gapChannel = repcap.GapChannel.Default) \n
		This command turns the relative limit check for the specified gap (CACLR) channel on and off. You have to activate the
		general ACLR limit check before using this command with method RsFsw.Calculate.Limit.AcPower.State.set. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
			:return: state: ON | OFF | 1 | 0"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:ACPower:GAP{gapChannel_cmd_val}:AUTO:ACLR:RELative:STATe?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RfPowerCls:
	"""RfPower commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rfPower", core, parent)

	def set(self, level: float) -> None:
		"""SCPI: TRIGger[:SEQuence]:LEVel:RFPower \n
		Snippet: driver.applications.k17Mcgd.trigger.sequence.level.rfPower.set(level = 1.0) \n
		This command defines the power level the RF input must exceed to cause a trigger event. Note that any RF attenuation or
		preamplification is considered when the trigger level is analyzed. If defined, a reference level offset is also
		considered. The input signal must be between 500 MHz and 8 GHz. \n
			:param level: For details on available trigger levels and trigger bandwidths, see the data sheet. Unit: DBM
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'TRIGger:SEQuence:LEVel:RFPower {param}')

	def get(self) -> float:
		"""SCPI: TRIGger[:SEQuence]:LEVel:RFPower \n
		Snippet: value: float = driver.applications.k17Mcgd.trigger.sequence.level.rfPower.get() \n
		This command defines the power level the RF input must exceed to cause a trigger event. Note that any RF attenuation or
		preamplification is considered when the trigger level is analyzed. If defined, a reference level offset is also
		considered. The input signal must be between 500 MHz and 8 GHz. \n
			:return: level: No help available"""
		response = self._core.io.query_str(f'TRIGger:SEQuence:LEVel:RFPower?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BstreamCls:
	"""Bstream commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bstream", core, parent)

	def set(self, unit: enums.BstreamUnit) -> None:
		"""SCPI: UNIT:BSTReam \n
		Snippet: driver.applications.k14Xnr5G.unit.bstream.set(unit = enums.BstreamUnit.BIT) \n
		This command selects the way the bit stream is displayed. \n
			:param unit: SYMbols Displays the bit stream using symbols BITs Displays the bit stream using bits
		"""
		param = Conversions.enum_scalar_to_str(unit, enums.BstreamUnit)
		self._core.io.write(f'UNIT:BSTReam {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.BstreamUnit:
		"""SCPI: UNIT:BSTReam \n
		Snippet: value: enums.BstreamUnit = driver.applications.k14Xnr5G.unit.bstream.get() \n
		This command selects the way the bit stream is displayed. \n
			:return: unit: SYMbols Displays the bit stream using symbols BITs Displays the bit stream using bits"""
		response = self._core.io.query_str(f'UNIT:BSTReam?')
		return Conversions.str_to_scalar_enum(response, enums.BstreamUnit)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OffsetCls:
	"""Offset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("offset", core, parent)

	def set(self, mode: enums.FftOffsetMode) -> None:
		"""SCPI: [SENSe]:DEMod:FFT:OFFSet \n
		Snippet: driver.applications.k91Wlan.sense.demod.fft.offset.set(mode = enums.FftOffsetMode.AUTO) \n
		This command specifies the start offset of the FFT for OFDM demodulation (not for the 'FFT Spectrum' display) . \n
			:param mode: AUTO | GICenter | PEAK AUTO The FFT start offset is automatically chosen to minimize the intersymbol interference. GICenter Guard Interval Center: The FFT start offset is placed to the center of the guard interval. PEAK The peak of the fine timing metric is used to determine the FFT start offset.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.FftOffsetMode)
		self._core.io.write(f'SENSe:DEMod:FFT:OFFSet {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.FftOffsetMode:
		"""SCPI: [SENSe]:DEMod:FFT:OFFSet \n
		Snippet: value: enums.FftOffsetMode = driver.applications.k91Wlan.sense.demod.fft.offset.get() \n
		This command specifies the start offset of the FFT for OFDM demodulation (not for the 'FFT Spectrum' display) . \n
			:return: mode: AUTO | GICenter | PEAK AUTO The FFT start offset is automatically chosen to minimize the intersymbol interference. GICenter Guard Interval Center: The FFT start offset is placed to the center of the guard interval. PEAK The peak of the fine timing metric is used to determine the FFT start offset."""
		response = self._core.io.query_str(f'SENSe:DEMod:FFT:OFFSet?')
		return Conversions.str_to_scalar_enum(response, enums.FftOffsetMode)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MeasCls:
	"""Meas commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("meas", core, parent)

	def set(self, file: str) -> None:
		"""SCPI: MMEMory:STORe:TA:MEAS \n
		Snippet: driver.applications.k60Transient.massMemory.store.ta.meas.set(file = '1') \n
		This command stores the current measurement results (all enabled traces of all windows) into the specified .csv file.
		Secure User Mode In secure user mode, settings that are stored on the instrument are stored to volatile memory, which is
		restricted to 256 MB. Thus, a 'memory limit reached' error can occur although the hard disk indicates that storage space
		is still available. To store data permanently, select an external storage location such as a USB memory device.
		For details, see 'Protecting Data Using the Secure User Mode'. \n
			:param file: path and file name
		"""
		param = Conversions.value_to_quoted_str(file)
		self._core.io.write(f'MMEMory:STORe:TA:MEAS {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class McsIndexCls:
	"""McsIndex commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mcsIndex", core, parent)

	def get(self) -> str:
		"""SCPI: FETCh:BURSt:MCSindex \n
		Snippet: value: str = driver.applications.k91Wlan.fetch.burst.mcsIndex.get() \n
		Queries the Modulation and Coding Scheme (MCS) index of the first analyzed PPDU. \n
			:return: mcs_index: No help available"""
		response = self._core.io.query_str(f'FETCh:BURSt:MCSindex?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ScDataCls:
	"""ScData commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scData", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: MMEMory:SELect:CHANnel[:ITEM]:SCData \n
		Snippet: driver.massMemory.select.channel.item.scData.set(state = False) \n
		This command includes or excludes source calibration data for an optional external generator when storing or loading a
		configuration file. Depending on the used command, either the items from the entire instrument (MMEMory:SELect[:ITEM]...)
		, or only those from the currently selected channel (MMEM:SELect:CHANnel[:ITEM]...) are stored or loaded. \n
			:param state: ON | OFF | 1 | 0
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'MMEMory:SELect:CHANnel:ITEM:SCData {param}')

	def get(self) -> bool:
		"""SCPI: MMEMory:SELect:CHANnel[:ITEM]:SCData \n
		Snippet: value: bool = driver.massMemory.select.channel.item.scData.get() \n
		This command includes or excludes source calibration data for an optional external generator when storing or loading a
		configuration file. Depending on the used command, either the items from the entire instrument (MMEMory:SELect[:ITEM]...)
		, or only those from the currently selected channel (MMEM:SELect:CHANnel[:ITEM]...) are stored or loaded. \n
			:return: state: ON | OFF | 1 | 0"""
		response = self._core.io.query_str(f'MMEMory:SELect:CHANnel:ITEM:SCData?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ReferenceCls:
	"""Reference commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("reference", core, parent)

	def set(self, reference: enums.DetectReferenceB) -> None:
		"""SCPI: [SENSe]:DETect:REFerence \n
		Snippet: driver.applications.k6Pulse.sense.detect.reference.set(reference = enums.DetectReferenceB.ABSolute) \n
		The reference level to be used for setting the pulse detection threshold. \n
			:param reference: REFLevel | PEAK | NOISe | ABSolute REFLevel Current reference level PEAK Peak level as measured over the entire capture data interval NOISe Noise level determined from the current capture data according to [SENSe:]TRACe:MEASurement:DEFine:DURation:MIN. ABSolute Absolute level defined by [SENSe:]DETect:THReshold.
		"""
		param = Conversions.enum_scalar_to_str(reference, enums.DetectReferenceB)
		self._core.io.write(f'SENSe:DETect:REFerence {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.DetectReferenceB:
		"""SCPI: [SENSe]:DETect:REFerence \n
		Snippet: value: enums.DetectReferenceB = driver.applications.k6Pulse.sense.detect.reference.get() \n
		The reference level to be used for setting the pulse detection threshold. \n
			:return: reference: REFLevel | PEAK | NOISe | ABSolute REFLevel Current reference level PEAK Peak level as measured over the entire capture data interval NOISe Noise level determined from the current capture data according to [SENSe:]TRACe:MEASurement:DEFine:DURation:MIN. ABSolute Absolute level defined by [SENSe:]DETect:THReshold."""
		response = self._core.io.query_str(f'SENSe:DETect:REFerence?')
		return Conversions.str_to_scalar_enum(response, enums.DetectReferenceB)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BurstCls:
	"""Burst commands group definition. 38 total commands, 7 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("burst", core, parent)

	@property
	def all(self):
		"""all commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_all'):
			from .All import AllCls
			self._all = AllCls(self._core, self._cmd_group)
		return self._all

	@property
	def trise(self):
		"""trise commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_trise'):
			from .Trise import TriseCls
			self._trise = TriseCls(self._core, self._cmd_group)
		return self._trise

	@property
	def tfall(self):
		"""tfall commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_tfall'):
			from .Tfall import TfallCls
			self._tfall = TfallCls(self._core, self._cmd_group)
		return self._tfall

	@property
	def freqError(self):
		"""freqError commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_freqError'):
			from .FreqError import FreqErrorCls
			self._freqError = FreqErrorCls(self._core, self._cmd_group)
		return self._freqError

	@property
	def symbolError(self):
		"""symbolError commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_symbolError'):
			from .SymbolError import SymbolErrorCls
			self._symbolError = SymbolErrorCls(self._core, self._cmd_group)
		return self._symbolError

	@property
	def iqOffset(self):
		"""iqOffset commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_iqOffset'):
			from .IqOffset import IqOffsetCls
			self._iqOffset = IqOffsetCls(self._core, self._cmd_group)
		return self._iqOffset

	@property
	def evm(self):
		"""evm commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_evm'):
			from .Evm import EvmCls
			self._evm = EvmCls(self._core, self._cmd_group)
		return self._evm

	def clone(self) -> 'BurstCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = BurstCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CstateCls:
	"""Cstate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cstate", core, parent)

	# noinspection PyTypeChecker
	def get(self) -> enums.ControlState:
		"""SCPI: CONFigure:GENerator:MCGD:CONNection:CSTate \n
		Snippet: value: enums.ControlState = driver.applications.k17Mcgd.configure.generator.mcgd.connection.cstate.get() \n
		Queries the state of the connected signal generator and its availability for the R&S FSW MCGD application. \n
			:return: state: OFF | SUCCessful | ERRor OFF No signal generator defined SUCCessful Connection established to compatible generator ERRor Connection error, for example due to an incompatible generator"""
		response = self._core.io.query_str(f'CONFigure:GENerator:MCGD:CONNection:CSTate?')
		return Conversions.str_to_scalar_enum(response, enums.ControlState)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StoreCls:
	"""Store commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("store", core, parent)

	def set(self, file_path: str) -> None:
		"""SCPI: [SENSe]:CORRection:FRESponse:USER:STORe \n
		Snippet: driver.sense.correction.fresponse.user.store.set(file_path = '1') \n
		Stores a saveset for a user-defined frequency response correction scenario. By default, the saveset is stored in the
		C:/R_S/INSTR/USER/FResponse directory. \n
			:param file_path: string
		"""
		param = Conversions.value_to_quoted_str(file_path)
		self._core.io.write(f'SENSe:CORRection:FRESponse:USER:STORe {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MorderCls:
	"""Morder commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("morder", core, parent)

	def set(self, state: enums.DpdOrder) -> None:
		"""SCPI: CONFigure:DPD:MORDer \n
		Snippet: driver.applications.k18AmplifierEt.configure.dpd.morder.set(state = enums.DpdOrder.AMFirst) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.enum_scalar_to_str(state, enums.DpdOrder)
		self._core.io.write(f'CONFigure:DPD:MORDer {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.DpdOrder:
		"""SCPI: CONFigure:DPD:MORDer \n
		Snippet: value: enums.DpdOrder = driver.applications.k18AmplifierEt.configure.dpd.morder.get() \n
		No command help available \n
			:return: state: No help available"""
		response = self._core.io.query_str(f'CONFigure:DPD:MORDer?')
		return Conversions.str_to_scalar_enum(response, enums.DpdOrder)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ManualCls:
	"""Manual commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("manual", core, parent)

	def set(self, channel_number: float) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:REFerence:TXCHannel:MANual \n
		Snippet: driver.sense.power.achannel.reference.txChannel.manual.set(channel_number = 1.0) \n
		This command defines a reference channel for relative ACLR measurements. You need at least one channel for the command to
		work. Note that this command is not available for MSR ACLR measurements (see method RsFsw.Calculate.Marker.Function.Power.
		preset) . \n
			:param channel_number: Range: 1 to 18
		"""
		param = Conversions.decimal_value_to_str(channel_number)
		self._core.io.write(f'SENSe:POWer:ACHannel:REFerence:TXCHannel:MANual {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:POWer:ACHannel:REFerence:TXCHannel:MANual \n
		Snippet: value: float = driver.sense.power.achannel.reference.txChannel.manual.get() \n
		This command defines a reference channel for relative ACLR measurements. You need at least one channel for the command to
		work. Note that this command is not available for MSR ACLR measurements (see method RsFsw.Calculate.Marker.Function.Power.
		preset) . \n
			:return: channel_number: Range: 1 to 18"""
		response = self._core.io.query_str(f'SENSe:POWer:ACHannel:REFerence:TXCHannel:MANual?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CenterCls:
	"""Center commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("center", core, parent)

	@property
	def channel(self):
		"""channel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_channel'):
			from .Channel import ChannelCls
			self._channel = ChannelCls(self._core, self._cmd_group)
		return self._channel

	def clone(self) -> 'CenterCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CenterCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FnameCls:
	"""Fname commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fname", core, parent)

	def set(self, filename: str) -> None:
		"""SCPI: CONFigure:DDPD:FNAMe \n
		Snippet: driver.applications.k18AmplifierEt.configure.ddpd.fname.set(filename = '1') \n
		This command defines a file name for the I/Q file that contains the predistorted I/Q data that was generated by the
		direct DPD.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on direct DPD (method RsFsw.Applications.K18_AmplifierEt.Configure.Ddpd.State.set) . \n
			:param filename: String containing the file name (including file type .wv) .
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'CONFigure:DDPD:FNAMe {param}')

	def get(self) -> str:
		"""SCPI: CONFigure:DDPD:FNAMe \n
		Snippet: value: str = driver.applications.k18AmplifierEt.configure.ddpd.fname.get() \n
		This command defines a file name for the I/Q file that contains the predistorted I/Q data that was generated by the
		direct DPD.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on direct DPD (method RsFsw.Applications.K18_AmplifierEt.Configure.Ddpd.State.set) . \n
			:return: filename: String containing the file name (including file type .wv) ."""
		response = self._core.io.query_str(f'CONFigure:DDPD:FNAMe?')
		return trim_str_response(response)
